@@ -2,9 +2,6 @@ use strict;
 use warnings;
 
 package Net::FreshBooks::API::Invoice;
-BEGIN {
-  $Net::FreshBooks::API::Invoice::VERSION = '0.12';
-}
 
 use Moose;
 extends 'Net::FreshBooks::API::Base';
@@ -31,7 +28,11 @@ sub _fields {
         discount           => { mutable => 1, },
         notes              => { mutable => 1, },
         terms              => { mutable => 1, },
+        currency_code      => { mutable => 1, },
+        folder             => { mutable => 1, },
+        language           => { mutable => 1, },
         return_uri         => { mutable => 1, },
+        updated            => { mutable => 0, },
 
         links => {
             mutable      => 0,
@@ -50,6 +51,8 @@ sub _fields {
         p_state      => { mutable => 1, },
         p_country    => { mutable => 1, },
         p_code       => { mutable => 1, },
+        vat_name     => { mutable => 1, },
+        vat_number   => { mutable => 1, },
 
         lines => {
             mutable      => 1,
@@ -112,20 +115,20 @@ Net::FreshBooks::API::Invoice
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
     my $fb = Net::FreshBooks::API->new({ ... });
     my $invoice = $fb->invoice;
 
-=head2 invoice->create
+=head2 create
 
 Create an invoice in the FreshBooks system.
 
 my $invoice = $fb->invoice->create({...});
 
-=head2 invoice->add_line
+=head2 add_line
 
 Create a new L<Net::FreshBooks::API::InvoiceLine> object and add it to the end
 of the list of lines
@@ -142,49 +145,39 @@ of the list of lines
         }
     );
 
-=head2 invoice->send_by_email
+=head2 send_by_email
 
 Send the invoice by email.
 
   my $result = $invoice->send_by_email();
 
-=head2 invoice->send_by_snail_mail
+=head2 send_by_snail_mail
 
 Send the invoice by snail mail.
 
   my $result = $invoice->send_by_snail_mail();
 
-=head2 invoice->update
+=head2 update
 
 Please see client->update for an example of how to use this method.
 
-=head2 invoice->get
+=head2 get
 
     my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
 
-=head2 invoice->delete
+=head2 delete
 
     my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
     $invoice->delete;
 
-=head2 invoice->links
+=head2 links
 
-Returns an object with three methods.  Each method returns a FreshBooks
-URL.
-
-=head4 invoice->links->client_view
+Returns a L<Net::FreshBooks::API::Links> object, which returns FreshBooks
+URLs.
 
     print "send this url to client: " . $invoice->links->client_view;
 
-=head4 invoice->links->view
-
-    print "view invoice in my account: " . $invoice->links->view;
-
-=head4 invoice->links->edit
-
-    print "edit invoice in my account: " . $invoice->links->edit;
-
-=head2 invoice->list
+=head2 list
 
 Returns a L<Net::FreshBooks::API::Iterator> object.
 
@@ -195,7 +188,7 @@ Returns a L<Net::FreshBooks::API::Iterator> object.
         print $invoice->invoice_id, "\n";
     }
 
-=head2 invoice->lines
+=head2 lines
 
 Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
 
@@ -208,10 +201,20 @@ Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
 This class gives you object to FreshBooks invoice information.
 L<Net::FreshBooks::API> will construct this object for you.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Edmund von der Burg <evdb@ecclestoad.co.uk>
+
+=item *
 
 Olaf Alders <olaf@wundercounter.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Edmund von der Burg & Olaf Alders.
