@@ -2,9 +2,6 @@ use strict;
 use warnings;
 
 package Net::FreshBooks::API::Recurring;
-BEGIN {
-  $Net::FreshBooks::API::Recurring::VERSION = '0.12';
-}
 
 use Moose;
 extends 'Net::FreshBooks::API::Invoice';
@@ -33,9 +30,13 @@ sub _fields {
         p_state         => { mutable => 1, },
         p_country       => { mutable => 1, },
         p_code          => { mutable => 1, },
+        vat_name        => { mutable => 1, },
+        vat_number      => { mutable => 1, },
         po_number       => { mutable => 1, },
         status          => { mutable => 0, },
         amount          => { mutable => 0, },
+        currency_code   => { mutable => 1, },
+        language        => { mutable => 1, },
         date            => { mutable => 1, },
         notes           => { mutable => 1, },
         terms           => { mutable => 1, },
@@ -43,6 +44,9 @@ sub _fields {
         return_uri      => { mutable => 1, },
         send_snail_mail => { mutable => 1, },
         send_email      => { mutable => 1, },
+
+        # autobill will need to be an object similar to InvoiceLine
+        #autobill        => { ... },
         lines           => {
             mutable      => 1,
             made_of      => 'Net::FreshBooks::API::InvoiceLine',
@@ -57,6 +61,7 @@ sub _fields {
 __PACKAGE__->meta->make_immutable();
 
 1;
+
 __END__
 =pod
 
@@ -66,7 +71,7 @@ Net::FreshBooks::API::Recurring
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -77,12 +82,7 @@ version 0.12
     # You will not access this module directly, but rather fetch an object via
     # its parent class, Net::FreshBooks::API
 
-    # auth_token and account_name come from FreshBooks
-    my $fb = Net::FreshBooks::API->new(
-        {   auth_token   => $auth_token,
-            account_name => $account_name,
-        }
-    );
+    my $fb = Net::FreshBooks::API->new({ ... });
 
     # create a new client
     my $client = $fb->client->create(
@@ -121,24 +121,24 @@ version 0.12
     See also L<Net::FreshBooks::API::Base> for other available methods, such
     as create, update, get, list and delete.
 
-=head2 recurring->create
+=head2 create
 
     my $recurring = $fb->recurring->create({...});
 
-=head2 recurring->update
+=head2 update
 
 Please see client->update for an example of how to use this method.
 
-=head2 recurring->get
+=head2 get
 
     my $item = $recurring->get({ recurring_id => $recurring_id });
 
-=head2 recurring->delete
+=head2 delete
 
     my $item = $recurring->get({ recurring_id => $recurring_id });
     $item->delete;
 
-=head2 recurring->list
+=head2 list
 
 Returns a L<Net::FreshBooks::API::Iterator> object.
 
@@ -147,7 +147,7 @@ Returns a L<Net::FreshBooks::API::Iterator> object.
         print $recurring->recurring_id, "\n";
     }
 
-=head2 recurring->lines
+=head2 lines
 
 Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
 
@@ -159,10 +159,6 @@ Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
 
 Net::FreshBooks::API::Recurring - FreshBooks Recurring Items
 
-=head1 VERSION
-
-version 0.12
-
 =head1 AUTHOR
 
     Olaf Alders
@@ -182,10 +178,20 @@ work on this module and for releasing it to the world.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Edmund von der Burg <evdb@ecclestoad.co.uk>
+
+=item *
 
 Olaf Alders <olaf@wundercounter.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Edmund von der Burg & Olaf Alders.
